<?php

var_dump(PHP_OUTPUT_HANDLER_CONT);
var_dump(PHP_OUTPUT_HANDLER_WRITE);

var_dump(PHP_OUTPUT_HANDLER_START);
var_dump(PHP_OUTPUT_HANDLER_CLEAN);
var_dump(PHP_OUTPUT_HANDLER_FLUSH);

var_dump(PHP_OUTPUT_HANDLER_END);
var_dump(PHP_OUTPUT_HANDLER_FINAL);

var_dump(PHP_OUTPUT_HANDLER_CLEANABLE);
var_dump(PHP_OUTPUT_HANDLER_FLUSHABLE);
var_dump(PHP_OUTPUT_HANDLER_REMOVABLE);
var_dump(PHP_OUTPUT_HANDLER_STDFLAGS);
